
import re
from django import forms
from django.core.exceptions import ValidationError

class KeyStringField(forms.CharField):
    def __init__(self, *args, **kwds):
        kwds["widget"] = forms.Textarea
        super().__init__(*args, **kwds)

    def to_python(self, value):
        """Split keystring on whitespace"""
        if not value:
            return []

        return re.split("\s+", value)

    def validate(self, value):
        """Check if there are at least two tokens"""
        super().validate(value)
        if len(value) < 2:
            raise ValidationError("KeyString needs type and key part")

    

class PublicKeyCreateForm(forms.Form):
    keystring = KeyStringField()
    hostname = forms.CharField(max_length=128)
    port = forms.IntegerField(required=False)
    client_cert = forms.BooleanField(required=False)
    public = forms.BooleanField(required=False)
