from base64 import b64encode, b64decode
import hashlib
from django.db import models

class SSHPublicKey(models.Model):
    hostname = models.CharField(max_length=128)
    port = models.IntegerField(null=True, blank=True)
    keytype = models.CharField(max_length=32)
    key = models.TextField()
    created = models.DateTimeField(auto_now_add=True)
    client_cert = models.BooleanField(default=False)

    def server(self):
        if self.port:
            return f"{self.hostname}:{self.port}"
        return self.hostname

    def __str__(self):
        return f"{self.hostname} ({self.keytype})"

    def fingerprint_sha256(self):
        raw_key = b64decode(self.key)
        digest = b64encode(hashlib.sha256(raw_key).digest())
        return digest.decode().replace("=", "")

    def fingerprint_md5(self):
        raw_key = b64decode(self.key)
        digest = hashlib.md5(raw_key).hexdigest()
        return ":".join(a + b for a, b in zip(digest[::2], digest[1::2]))
